/*
 * GUIErrors.java
 *
 * Version:
 *    $Id: GUIErrors.java,v 1.1 2005/06/19 21:18:10 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: GUIErrors.java,v $
 *    Revision 1.1  2005/06/19 21:18:10  gap7472
 *    Initial revision
 *
 */

import java.awt.*;

import javax.swing.*;

/**
 * This class provides pre-written error dialog boxes that are shown
 * to the user when the GUI encounters problems.
 *
 * The dialogs are kept in this class to simplify the code used in
 * other parts of the GUI.
 *
 * @author  Guy Paddock (gap7472@rit.edu)
 */
public class GUIErrors
{
    /**
     * This method will display an error message dialog box to handle
     * being unable to read a user-supplied text file.
     *
     * @param   parent  The parent dialog or frame for the error
     *                  dialog.
     */
    public static void errorReadingInput(Component parent)
    {
        JOptionPane.showMessageDialog(
        parent,
        "<html><p style='width: 300px; margin-bottom: 5px'>"         +
        "An error occurred while attempting to read the input text " +
        "file.</p>"                                                  +
        
        "<p style='width: 300px; margin-bottom: 5px'>"               +
        "The file may be inaccessible or has been removed, or you "  +
        "might not have the proper credentials to read it.</p>"      +

        "<p>Please select a different file.</p></html>",
        "Error Reading Input File",
        JOptionPane.ERROR_MESSAGE);
    }

    /**
     * This method will display an error message dialog box to handle
     * being unable to save results to a user-specified location.
     *
     * @param   parent  The parent dialog or frame for the error
     *                  dialog.
     */
    public static void errorSavingResults(Component parent)
    {
        JOptionPane.showMessageDialog(
        parent,
        "<html><p style='width: 300px; margin-bottom: 5px'>"         +
        "An error occurred while attempting to save the results to " +
        "a file.</p>"                                                +
        
        "<p style='width: 300px; margin-bottom: 5px'>"               +
        "The file may be read-only or inaccessible, or you might "   +
        "not have the proper credentials to save it to the "         +
        "location you specified.</p>"                                +

        "<p>Please try again.</p></html>",
        "Error Saving Results to File",
        JOptionPane.ERROR_MESSAGE);
    }

    /**
     * This method will display a warning message dialog box to
     * handle running out of heap memory while running the greedy
     * algorithm.
     *
     * @param   parent  The parent dialog or frame for the error
     *                  dialog.
     */
    public static void errorOutOfMemory(Component parent)
    {
        JOptionPane.showMessageDialog(
            parent,
            "<html><p style='width: 435; margin-bottom: 10px'>"      +
            "The Profiler has run out of heap memory while running " +
            "the greedy algorithm.<br><br>"                          +

            "Please reduce the number of fragments, decrease the "   +
            "initial data size, or invoke the profiler with more "   +
            "heap space, as follows:</p>"                            +
            "<p style='font-weight: normal'>"                        +
            "java -Xmx512m ProfilerGUI"                              +
            "</p></html>",
            "Profiler Out of Memory",
            JOptionPane.WARNING_MESSAGE);
    }
}