/*
 * TextFileFilter.java
 *
 * Version:
 *    $Id: TextFileFilter.java,v 1.1 2005/06/20 00:59:26 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: TextFileFilter.java,v $
 *    Revision 1.1  2005/06/20 00:59:26  gap7472
 *    Initial revision
 *
 */

import java.io.*;

/**
 * A FileFilter that filters all files that are not text files, for
 * display in an open or save dialog box.
 *
 * @author  Guy Paddock (gap7472@rit.edu)
 */
class TextFileFilter extends javax.swing.filechooser.FileFilter
{
    /**
     * A utility method for obtaining the extension from a file
     *
     * @param   file    The file whose extension will be obtain
     * @return          The file extension of the specified file
     */
    private static String getExtension(File file)
    {
        String  extension   = null,
                filename    = file.getName();
        int     dotPos      = filename.lastIndexOf('.');

        if ((dotPos > 0) && (dotPos < (filename.length() - 1)))
            extension = filename.substring(dotPos + 1).toLowerCase();

        return (extension);
    }

    /**
     * This method tells the dialog box what files to show and what
     * files to filter out. It takes a file as an argument and
     * returns a boolean to indicate if the file should be shown in
     * the list of files.
     *
     * @param   file    The file whose visibility is to be determined
     * @return          True if the specified file should be
     *                  displayed, false if it should be hidden
     */
    public boolean accept(File file)
    {
        String extension;

        // Directories should be shown at all times
        if (file.isDirectory())
            return (true);

        extension   = getExtension(file);

        // Only accept text files
        if ((extension != null) && extension.equals("txt"))
            return (true);

        return (false);
    }

    /**
     * This method returns a textual description of this filter, to
     * display to the user in the list of file-type filters.
     *
     * @return  A description of what type of files this filter
     *          pertains to -- "Text Files".
     */
    public String getDescription()
    {
        return "Text Files";
    }
}