/*
 * GraphArc.java
 *
 * Version:
 *    $Id: GraphArc.java,v 1.6 2005/06/20 01:32:02 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: GraphArc.java,v $
 *    Revision 1.6  2005/06/20 01:32:02  gap7472
 *    No changes.
 *
 *    Revision 1.5  2005/06/08 02:52:50  gap7472
 *    Minor changes.
 *
 *    Revision 1.1  2005/04/06 05:54:17  gap7472
 *    Initial revision
 *
 *
 */

package alg.greedy;

import util.heap.*;

/**
 * This class implements a weighted arc.
 *
 * @author  Guy Paddock
 */
public class GraphArc implements WeightedObject
{
    /**
     * Information about the overlap represented by this arc.
     */
    private OverlapInfo  overlapInfo;

    /**
     * The node to which this arc is pointed.
     */
    private GraphNode   head,
                        tail;

    /**
     * Constructor for GraphArc. Does not take head and
     * tail parameters.
     *
     * @param   overlap The overlap that this arc represents.
     */
    public GraphArc(OverlapInfo overlapInfo)
    {
        this(overlapInfo, null, null);
    }

    /**
     * Constructor for GraphArc.
     *
     * @param   overlap The overlap that this arc represents.
     * @param   head    The node to which this arc is pointing.
     * @param   head    The node from which this arc is pointing.
     */
    public GraphArc(OverlapInfo overlapInfo, GraphNode head, GraphNode tail)
    {
        setOverlapInfo(overlapInfo);
        setHead(head);
        setTail(tail);
    }

    /**
     * Accessor for overlapInfo.
     *
     * @return  the value stored in overlapInfo
     */
    public OverlapInfo getOverlapInfo()
    {
        return (overlapInfo);
    }

    /**
     * Modifier for overlapInfo.
     *
     * @param   overlap The new value for overlapInfo
     */
    public void setOverlapInfo(OverlapInfo overlapInfo)
    {
        this.overlapInfo    = overlapInfo;
    }

    /**
     * Short-hand accessor for overlapInfo.getOverlap()
     *
     * @return  the return value of overlapInfo.getOverlap()
     */
    public String getOverlap()
    {
        return (overlapInfo.getOverlap());
    }

    /**
     * Accessor for head.
     *
     * @return  the value stored in head
     */
    public GraphNode getHead()
    {
        return (head);
    }

    /**
     * Modifier for head.
     *
     * @param   head    The new node to which the arc should point.
     */
    public void setHead(GraphNode head)
    {
        this.head       = head;
    }

    /**
     * Accessor for tail.
     *
     * @return  the value stored in tail
     */
    public GraphNode getTail()
    {
        return (tail);
    }

    /**
     * Modifier for tail.
     *
     * @param   tail    The new node to which the arc should point.
     */
    public void setTail(GraphNode tail)
    {
        this.tail       = tail;
    }

    /**
     * Method to get the weight of an arc based upon
     * the length of the overlap it contains.
     *
     * @return  The weight of the arc.
     */
    public int getWeight()
    {
        return (getOverlap().length());
    }
}