/*
 * OverlapInfo.java
 *
 * Version:
 *    $Id: OverlapInfo.java,v 1.7 2005/06/20 01:32:02 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: OverlapInfo.java,v $
 *    Revision 1.7  2005/06/20 01:32:02  gap7472
 *    No changes.
 *
 *    Revision 1.5  2005/04/13 06:17:36  gap7472
 *    Normalized line endings.
 *
 *    Revision 1.4  2005/04/13 06:07:53  gap7472
 *    Added comments.
 *
 *    Revision 1.1  2005/04/06 05:54:17  gap7472
 *    Initial revision
 */

package alg.greedy;

/**
 * This class encapsulates information about the overlap
 * between two strings.
 * 
 * @author  Guy Paddock
 */
public class OverlapInfo
{
    /**
     * The overlap string itself.
     */
    String  theOverlap;

    /**
     * Where the overlap begins in the suffix of the
     * first string.
     */
    int     startPos;

    /**
     * Constructor for OverlapInfo.
     *
     * @param   theOverlap  The overlap represented by this instance.
     * @param   startPos    The starting position of the position in
     *                      the string.
     */
    public OverlapInfo(String theOverlap, int startPos)
    {
        setOverlap(theOverlap);
        setStart(startPos);
    }

    /**
     * Modifier for the overlap stored in the
     * instance.
     *
     * @param   theOverlap  The overlap to store.
     */
    public void setOverlap(String theOverlap)
    {
        this.theOverlap = theOverlap;
    }

    /**
     * Modifier for the starting position of the
     * overlap.
     *
     * @param   startPos    The new starting position
     *                      to store in the instance.
     */
    public void setStart(int startPos)
    {
        this.startPos   = startPos;
    }

    /**
     * Accessor for the overlap stored in the
     * instance.
     *
     * @return  the overlap stored in this instance.
     */
    public String getOverlap()
    {
        return (theOverlap);
    }

    /**
     * Accessor for the starting position stored
     * in the instance.
     *
     * @return  the starting position stored in the
     *          instance
     */
    public int getStart()
    {
        return (startPos);
    }
}      