/*
 * AbstractArc.java
 *
 * Version:
 *    $Id: AbstractArc.java,v 1.4 2005/06/20 01:54:31 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: AbstractArc.java,v $
 *    Revision 1.4  2005/06/20 01:54:31  gap7472
 *    -Package changed from SuffixTree -> util.suffixtree.
 *
 *    Revision 1.2  2005/03/16 07:26:19  gap7472
 *    Fixed implementation of the search so that it now pertains
 *    to provided specifications.
 *
 *    Revision 1.1  2005/03/16 05:57:55  gap7472
 *    Initial revision
 *
 *    Revision 1.2  2005/03/09 07:09:28  gap7472
 *    Minor comment changes.
 *
 *    Revision 1.1  2005/03/09 07:01:48  gap7472
 *    Initial revision
 *
 */

package util.suffixtree;

import java.util.*;

/**
 * This class represents an abstract arc, and is
 * the parent to Arc and EmptyArc.
 */
public abstract class AbstractArc
{
    /**
     * Inserts a specified suffix value into this Arc.
     *
     * @param   suffix  suffix to insert into this Arc
     * @param   pos     position where the suffix occurs in the original string
     *
     * @return          an Arc with the specified suffix linked in
     */
    public abstract AbstractArc insert(String suffix, int pos);

    /**
     * Attempts to find and return the location of a specified
     * target in this arc.
     *
     * @param   target  the target string to find
     * @return          a tree map of matches for the specified suffix sorted
     *                  by position, or null if the suffix was not found
     *
     * @throws  ContainmentException    if the specified target has
     *                                  multiple possible paths
     */
    public abstract TreeMap<Integer, String> findTarget(String target, String curPath)
    throws ContainmentException;
}