/*
 * EmptyArc.java
 *
 * Version:
 *    $Id: EmptyArc.java,v 1.4 2005/06/20 01:54:31 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: EmptyArc.java,v $
 *    Revision 1.4  2005/06/20 01:54:31  gap7472
 *    -Package changed from SuffixTree -> util.suffixtree.
 *
 *    Revision 1.2  2005/03/16 07:26:19  gap7472
 *    Fixed implementation of the search so that it now pertains
 *    to provided specifications.
 *
 *    Revision 1.1  2005/03/16 05:57:55  gap7472
 *    Initial revision
 *
 *    Revision 1.2  2005/03/09 07:09:28  gap7472
 *    Minor comment changes.
 *
 *    Revision 1.1  2005/03/09 07:01:48  gap7472
 *    Initial revision
 *
 */

package util.suffixtree;

import java.util.*;

/**
 * This class represents an Arc that is empty -- one that
 * contains no label and does not link to anything.
 *
 * @author  Guy Paddock
 */
public class EmptyArc extends AbstractArc
{
    /**
     * Inserts a specified suffix value into this Arc by
     * creating a non-empty Arc with the specified suffix
     * as its label and a head that contains the specified
     * location.
     *
     * @param   suffix  suffix to insert into this Arc
     * @param   pos     position that the suffix occurs in
     *                  the original string
     *
     * @return          a new Arc with the specified suffix
     *                  linked in
     */
    public Arc insert(String suffix, int pos)
    {
        // We're an empty node so use the suffix and
        // location we have to create a new, non-empty arc
        return (new Arc(suffix, pos));
    }

    /**
     * Attempts to find and return the location of a specified
     * target in this arc.
     *
     * @param   target  the target string to find
     * @return          Always null because this arc doesn't
     *                  contain anything
     *
     * @throws  ContainmentException    if the specified target has
     *                                  multiple possible paths
     */
    public TreeMap<Integer, String> findTarget(String target, String curPath)
    throws ContainmentException
    {
        // We have no match -- we're an empty arc!
        return (null);
    }
}