/*
 * SleepThread.java
 *
 * Version:
 *    $Id: SleepThread.java,v 1.1 2005/06/20 01:43:23 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: SleepThread.java,v $
 *    Revision 1.1  2005/06/20 01:43:23  gap7472
 *    Initial revision
 *
 */

package util;

/**
 * A slightly modified version of Thread that simplifies
 * calls to sleep() by removing the requirement for the
 * calls to be enclosed in try...catch blocks.
 *
 * @author  Guy Paddock (gap7472@rit.edu)
 */
public class SleepThread extends Thread
{
    /**
     * @see java.lang.Thread#Thread()
     */
    public SleepThread()
    {
        super();
    }

    /**
     * @see java.lang.Thread#Thread(java.lang.Runnable)
     */
    public SleepThread(Runnable target)
    {
        super(target);
    }

    /**
     * @see java.lang.Thread#Thread(java.lang.Runnable,
     *                              java.lang.String)
     */
     public SleepThread(Runnable target, String name)
    {
        super(target, name);
    }

    /**
     * @see java.lang.Thread#Thread(java.lang.String)
     */
    public SleepThread(String name)
    {
        super(name);
    }

    /**
     * @see java.lang.Thread#Thread(java.lang.ThreadGroup,
     *                              java.lang.Runnable)
     */
    public SleepThread(ThreadGroup group, Runnable target)
    {
        super(group, target);
    }

    /**
     * @see java.lang.Thread#Thread(java.lang.ThreadGroup,
     *                              java.lang.Runnable,
     *                              java.lang.String)
     */
    public SleepThread(ThreadGroup group, Runnable target,
                       String name)
    {
        super(group, target, name);
    }
     
    /**
     * @see java.lang.Thread#Thread(java.lang.ThreadGroup,
     *                              java.lang.Runnable,
     *                              java.lang.String,
     *                              long)
     */
    public SleepThread(ThreadGroup group, Runnable target,
                       String name, long stackSize)
    {
        super(group, target, name, stackSize);
    }

    /**
     * @see java.lang.Thread#Thread(java.lang.ThreadGroup,
     *                              java.lang.String)
     */
    public SleepThread(ThreadGroup group, String name)
    {
        super(group, name);
    }

    /**
     * This is the only modification from the parent class. Unlike
     * Thread's sleep() method, this version does not throw
     * InterruptedException. This method simply invokes Thread's
     * sleep and throws away the exception, if it occurs.
     *
     * @see     java.lang.Thread#sleep
     * @param   millis  the length of time to sleep in milliseconds.
     */
    public static void sleep(long millis)
    {
        try
        {
            Thread.sleep(millis);
        }

        catch (InterruptedException unused)
        {
            // Do nothing
        }
    }
}