/*
 * Heap.java
 *
 * Version:
 *    $Id: Heap.java,v 1.1 2005/06/20 01:46:03 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: Heap.java,v $
 *    Revision 1.1  2005/06/20 01:46:03  gap7472
 *    Initial revision
 *
 */

package util.heap;

/**
 * An abstract Heap. This class merely outlines the basic methods
 * that a heap should provide; how they are implemented depends
 * entirely upon the child class.
 *
 * @author  Guy Paddock (gap7472@rit.edu)
 */
public abstract class Heap<T extends WeightedObject>
{
    /**
     * Returns how many items are stored in the heap.
     *
     * @return  The number of items stored in the heap
     */
    public abstract int size();

    /**
     * This is used to detect if the heap is empty.
     *
     * @return  True if the heap is empty, false otherwise.
     */
    public abstract boolean isEmpty();

    /**
     * This is used to detect if the heap is full.
     *
     * @return  True if the heap is at capacity, false otherwise.
     */
    public abstract boolean isFull();

    /**
     * This is used to examine the item at the top of the heap
     * without removing it.
     *
     * @return  The item at the top of the heap.
     */
    public abstract T peek();

    /**
     * This inserts a new element into the bottom of the heap,
     * then positions it properly.
     *
     * @param   newElement  The new element to insert into the heap.
     */
    public abstract void push(T newElement);

    /**
     * This removes the topmost element and sorts the heap accordingly.
     *
     * @return  the top-most element of the heap, or null if the
     *          heap is empty.
     */
    public abstract T pop();
}