/*
 * WeightedString.java
 *
 * Version:
 *    $Id: WeightedString.java,v 1.2 2005/06/20 01:46:03 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: WeightedString.java,v $
 *    Revision 1.2  2005/06/20 01:46:03  gap7472
 *    -Package changed from GreedyAlg -> util.heap.
 *
 *    Revision 1.1  2005/06/08 03:13:57  gap7472
 *    Initial revision
 *
 */

package util.heap;

/**
 * This class encapsulates a string as a weighted
 * object, with a weight based on its length.
 *
 * @author  Guy Paddock
 */
public class WeightedString implements WeightedObject
{
    /**
     * The actual string.
     */
    String value;

    /**
     * Constructor for WeightedString.
     *
     * @param   value   The value of the new weighted string.
     */
    public WeightedString(String value)
    {
        setValue(value);
    }

    /**
     * Accessor for the string value.
     *
     * @return  The string instance contained within.
     */
    public String getValue()
    {
        return (value);
    }

    /**
     * Mutator for the string value.
     *
     * @param   value   The new value for the string
     *                  contained within this instance.
     */
    public void setValue(String value)
    {
        this.value = value;
    }

    /**
     * Method to obtain the weight of this object,
     * per the terms established in WeightedObject
     * interface.
     *
     * @return  int     The weight of the string in
     *                  this object, which is equal
     *                  to the string's length
     */
    public int getWeight()
    {
        return (value.length());
    }

    /**
     * Method to convert the weighted string to a
     * string (i.e. return the internal string).
     *
     * @return  the string inside as the string
     *          representation of this object
     */
    public String toString()
    {
        return (value);
    }
}