/*
 * LeafNode.java
 *
 * Version:
 *    $Id: LeafNode.java,v 1.4 2005/06/20 01:54:31 gap7472 Exp gap7472 $
 *
 * Revisions:
 *    $Log: LeafNode.java,v $
 *    Revision 1.4  2005/06/20 01:54:31  gap7472
 *    -Package changed from SuffixTree -> util.suffixtree.
 *
 *    Revision 1.2  2005/03/16 07:26:19  gap7472
 *    Fixed implementation of the search so that it now pertains
 *    to provided specifications.
 *
 *    Revision 1.1  2005/03/16 05:57:55  gap7472
 *    Initial revision
 *
 *    Revision 1.2  2005/03/09 07:09:28  gap7472
 *    Minor comment changes.
 *
 *    Revision 1.1  2005/03/09 07:01:48  gap7472
 *    Initial revision
 *
 */

package util.suffixtree;

import java.util.*;

/**
 * LeafNodes store the locations where a suffix occurs
 * in a word. They are the head of the arc path that
 * leads to each particular suffix.
 */
class LeafNode extends Node
{
    /**
     * Location(s) in which this suffix appears.
     */
    private int pos;

    /**
     * Constructor for LeafNode.
     *
     */
	public LeafNode()
	{
        pos = 0;
    }

    /**
     * Constructor for LeafNode. Initializes the
     * list of locations with one initial location.
     *
     * @param   initLoc     The initial location
     */
    public LeafNode(int pos)
    {
        // Call other constructor
        this();

        setPos(pos);
    }

    /**
     * Accessor for pos.
     *
     * @return  The suffix position stored in this Node.
     */
    public int getPos()
    {
        return (pos);
    }

    /**
     * Writer for pos.
     *
     * @param   pos     The new suffix position to store in
     *                  this Node.
     */
    public void setPos(int pos)
    {
        this.pos = pos;
    }
}